Under-sampling-based ensembles — imbalanced-ensemble 0.1.0 documentation

# Under-sampling-based ensembles

The `imbalanced_ensemble.ensemble.under_sampling` submodule contains a set of under-sampling-based ensemble imbalanced learning methods.

`SelfPacedEnsembleClassifier`([…]) | A self-paced ensemble (SPE) Classifier for class-imbalanced learning.
`BalanceCascadeClassifier`([base_estimator, …]) | A balance-cascade Classifier for class-imbalanced learning.
`BalancedRandomForestClassifier`(**kwargs) | A balanced random forest classifier.
`EasyEnsembleClassifier`(**kwargs) | Bag of balanced boosted learners also known as EasyEnsemble.
`RUSBoostClassifier`(**kwargs) | Random under-sampling integrated in the learning of AdaBoost.
`UnderBaggingClassifier`(**kwargs) | A Bagging classifier with intergrated random under-sampling.